@@ -1,8 +1,5 @@
-/* Copyright (c) 2002-2017 Pigeonhole authors, see the included COPYING file
- */
-
-#ifndef __SIEVE_CONFIG_H
-#define __SIEVE_CONFIG_H
+#ifndef SIEVE_CONFIG_H
+#define SIEVE_CONFIG_H
 
 #include "pigeonhole-config.h"
 #include "pigeonhole-version.h"
@@ -12,6 +9,9 @@
 #define SIEVE_SCRIPT_FILEEXT "sieve"
 #define SIEVE_BINARY_FILEEXT "svbin"
 
-#define DEFAULT_ENVELOPE_SENDER "MAILER-DAEMON"
+#define DEFAULT_ENVELOPE_SENDER \
+	SMTP_ADDRESS_LITERAL("MAILER-DAEMON", NULL)
+
+#define DEFAULT_REDIRECT_DUPLICATE_PERIOD (3600 * 12)
 
 #endif
